Plot fitted coefficient functions
plot_coefficients.RdPlots fitted expert or gating coefficient functions over the VCMoE grid.
Usage
plot_coefficients(object, type = c("expert", "gating"))plot_coefficients.RdPlots fitted expert or gating coefficient functions over the VCMoE grid.
plot_coefficients(object, type = c("expert", "gating"))